[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [52561] trunk/blender/source/blender/ makesrna/intern/rna_scene_api.c: Fix #33312: cycles render crash with motion blur / vector pass rendering.

Brecht Van Lommel brechtvanlommel at pandora.be
Mon Nov 26 10:46:17 CET 2012


Revision: 52561
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=52561
Author:   blendix
Date:     2012-11-26 09:46:15 +0000 (Mon, 26 Nov 2012)
Log Message:
-----------
Fix #33312: cycles render crash with motion blur / vector pass rendering. It's
actually the render threading issue and not a full fix, but this avoids the 3D
viewport getting redrawn when changing frames to get motion vectors.

Modified Paths:
--------------
    trunk/blender/source/blender/makesrna/intern/rna_scene_api.c

Modified: trunk/blender/source/blender/makesrna/intern/rna_scene_api.c
===================================================================
--- trunk/blender/source/blender/makesrna/intern/rna_scene_api.c	2012-11-26 08:52:07 UTC (rev 52560)
+++ trunk/blender/source/blender/makesrna/intern/rna_scene_api.c	2012-11-26 09:46:15 UTC (rev 52561)
@@ -62,12 +62,16 @@
 	BKE_scene_update_for_newframe(G.main, scene, (1 << 20) - 1);
 	BKE_scene_camera_switch_update(scene);
 
-	/* cant use NC_SCENE|ND_FRAME because this causes wm_event_do_notifiers to call
-	 * BKE_scene_update_for_newframe which will loose any un-keyed changes [#24690] */
-	/* WM_main_add_notifier(NC_SCENE|ND_FRAME, scene); */
-	
-	/* instead just redraw the views */
-	WM_main_add_notifier(NC_WINDOW, NULL);
+	/* don't do notifier when we're rendering, avoid some viewport crashes
+	 * redrawing while the data is being modified for render */
+	if(!G.is_rendering) {
+		/* cant use NC_SCENE|ND_FRAME because this causes wm_event_do_notifiers to call
+		 * BKE_scene_update_for_newframe which will loose any un-keyed changes [#24690] */
+		/* WM_main_add_notifier(NC_SCENE|ND_FRAME, scene); */
+		
+		/* instead just redraw the views */
+		WM_main_add_notifier(NC_WINDOW, NULL);
+	}
 }
 
 static void rna_Scene_update_tagged(Scene *scene)




More information about the Bf-blender-cvs mailing list